#
# git clone https://github.com/dirkvdb/ffmpegthumbnailer.git
# cd ffmpegthumbnailer
# DATE=$(git log -1 --format="%cd" --date=short | sed "s|-||g")
# git config tar.tar.xz.command "xz -c"
# git archive --format=tar.xz -o ffmpegthumbnailer-${DATE}.tar.xz --prefix=ffmpegthumbnailer-${DATE}/ master
#

%global gitdate		20220218

%define major		4
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		ffmpegthumbnailer
Version:	2.2.2%{?gitdate:^git%gitdate}
Release:	%mkrel 1
Summary:	Lightweight video thumbnailer
License:	GPLv2+
Group:		Video/Utilities
URL:		https://github.com/dirkvdb/ffmpegthumbnailer
%if 0%{?gitdate}
Source0:	%{name}-%{gitdate}.tar.xz
%else
Source0:	https://github.com/dirkvdb/%{name}/releases/download/%{version}/%{name}-%{version}.tar.bz2
%endif
BuildRequires:	cmake
BuildRequires:	ffmpeg-devel
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libjpeg)

%description
This video thumbnailer can be used by file managers to
create thumbnails for your video files. The thumbnailer
uses ffmpeg to decode frames from the video files, so
supported video formats depend on the configuration
flags of ffmpeg.

This thumbnailer was designed to be as fast and
lightweight as possible.

%package -n	%{libname}
Summary:	Main library for %{name}
Group:		Video/Utilities
Obsoletes:	%{mklibname %{name} 2}

%description -n	%{libname}
Main library for %{name}.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Development files for %{name}.

%prep
%autosetup -n %{name}-%{?gitdate}%{!?gitdate:%version} -p1

%build
%cmake \
	-DENABLE_STATIC=OFF \
	-DENABLE_GIO=ON \
	-DENABLE_THUMBNAILER=ON
%cmake_build

%install
%cmake_install

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%doc AUTHORS ChangeLog README TODO
%{_bindir}/%{name}
%{_datadir}/thumbnailers/%{name}.thumbnailer
%{_mandir}/man1/%{name}.1*

%files -n %{libname}
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files -n %{develname}
%{_libdir}/*.so
%{_includedir}/libffmpegthumbnailer/
%{_libdir}/pkgconfig/*.pc


%changelog
* Sat Apr 23 2022 wally <wally> 2.2.2^git20220218-1.mga9
+ Revision: 1852825
- update to latest git snapshot to fix build with ffmpeg5
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Mon May 25 2020 daviddavid <daviddavid> 2.2.2-1.mga8
+ Revision: 1587491
- new version: 2.2.2
- enable register thumbnailer support

* Tue Feb 11 2020 umeabot <umeabot> 2.2.0-6.mga8
+ Revision: 1489051
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 09 2018 wally <wally> 2.2.0-5.mga7
+ Revision: 1257919
- rebuild for aarch64

* Mon Apr 23 2018 zezinho <zezinho> 2.2.0-4.mga7
+ Revision: 1221728
- rebuild against ffmpeg 4

* Tue May 02 2017 akien <akien> 2.2.0-3.mga6
+ Revision: 1098284
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 2.2.0-2.mga6
+ Revision: 1089852
- Rebuild for ffmpeg 3.2.4

* Sun Jan 01 2017 daviddavid <daviddavid> 2.2.0-1.mga6
+ Revision: 1079202
- new version: 2.2.0

* Sun Feb 21 2016 daviddavid <daviddavid> 2.1.1-1.mga6
+ Revision: 975058
- new version: 2.1.1

* Sun Feb 14 2016 umeabot <umeabot> 2.1.0-2.mga6
+ Revision: 960074
- Mageia 6 Mass Rebuild

* Wed Sep 30 2015 daviddavid <daviddavid> 2.1.0-1.mga6
+ Revision: 885250
- new version: 2.1.0

* Sun Aug 02 2015 daviddavid <daviddavid> 2.0.10-1.mga6
+ Revision: 860652
- new version: 2.0.10
- update URL and Source URL
- remove no more needed Patch0
- switch to cmake build (upstream)
- fix mandir and libdir path (CMakeLists.txt)
- update file list

* Fri Nov 14 2014 akien <akien> 2.0.8-10.mga5
+ Revision: 797143
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 2.0.8-9.mga5
+ Revision: 747235
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0.8-8.mga5
+ Revision: 679171
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 2.0.8-7.mga4
+ Revision: 529954
- Mageia 4 Mass Rebuild

* Mon Jul 15 2013 fwang <fwang> 2.0.8-6.mga4
+ Revision: 454480
- rebuild for new ffmpeg

* Sun Jun 02 2013 fwang <fwang> 2.0.8-4.mga4
+ Revision: 434933
- fix build with latest libpng
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 2.0.8-3.mga3
+ Revision: 350261
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 2.0.8-2.mga3
+ Revision: 341580
- rebuild for new ffmpeg

* Sat Sep 29 2012 fwang <fwang> 2.0.8-1.mga3
+ Revision: 299978
- update rpm group
- new version 2.0.8

* Tue May 29 2012 fwang <fwang> 2.0.7-3.mga3
+ Revision: 248984
- fix build with latest ffmpeg
- rebuild for new ffmpeg

* Sun Sep 11 2011 fwang <fwang> 2.0.7-2.mga2
+ Revision: 142267
- rebuild for new libpng

* Wed Sep 07 2011 tv <tv> 2.0.7-1.mga2
+ Revision: 140282
- new release

* Fri Jun 24 2011 fwang <fwang> 2.0.6-2.mga2
+ Revision: 113120
- fix build with ffmpeg 0.8
- rebuild for new ffmpeg

* Thu Feb 17 2011 ahmad <ahmad> 2.0.6-1.mga1
+ Revision: 53161
- imported package ffmpegthumbnailer

